#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */
#include "Echo.h" /* Include Echo driver */


extern unsigned char *echoNextMessage;
extern unsigned char echoTransmitBuffer[];
extern unsigned char echoRSSIResult;

/* user variable */

byte send_flag = 0;

#define SEND_A 1
#define SEND_B 2


void main(void) {

  EnableInterrupts; /* enable interrupts */
  /* include your code here */



  SOPT_COPE = 0;
  Echo_Initialize();        /* Echo init */
  Echo_Enable();            /* Echo enable */
  EnableInterrupts; /* enable interrupts */
  while(Echo_DriverStatus().Bits.EnableDelay == 1);    /* wait to enable echo */
  
  /* Configure bank A */
  Echo_ChangeBank(ECHO_BANK_A);
  while(Echo_DriverStatus().Bits.Busy == 1);
  /* Configure for 434MHz and a frequency deviation of around 100kHz				*/
  Echo_SetFreqFskNoFRM(0x7E4, (0x700 - 10), (0x700 + 10));
	while(Echo_DriverStatus().Bits.Busy == 1);
	
	/* Configure bank B */
  Echo_ChangeBank(ECHO_BANK_B);
  while(Echo_DriverStatus().Bits.Busy == 1);
  /* Configure for 434MHz and ook modulation*/
  Echo_SetFreqOok(0x7E4);
	while(Echo_DriverStatus().Bits.Busy == 1);
	
	/* Configure bank to switching mode  */
  Echo_ChangeBank(ECHO_BANK_BOTH);
  while(Echo_DriverStatus().Bits.Busy == 1);
  

for(;;) 
  {    
    /* testing new messages */
    if(Echo_DriverStatus().Bits.MsgReady == 1)
    {
      /* New message is in receive buffer */
      if(((echoNextMessage[0]) & ECHO_CHECKSUM_ERROR) == 0)     /* Is checksum ok ? */
      {
        /* Which bank of register receive a message ? */
        if(((echoNextMessage[0]) & ECHO_BANKS_BIT) == ECHO_BANK_A)
        { /* Message receive by bank A */
          
          /* This is place for your code */
          
          /* You can set up out going messade */
        		
        		/* Set up the message to transmit												*/
        	echoTransmitBuffer[0] = 10;			// repeats
        	echoTransmitBuffer[1] = 1;			// spacing
        	echoTransmitBuffer[2] = ECHO_ID_VALUE;		// ID
        	echoTransmitBuffer[3] = 2;			// data length
        	echoTransmitBuffer[4] = 0x52;			// example data
        	echoTransmitBuffer[5] = 0x86;			// second example data byte
          
          send_flag = SEND_A;      
        } else
        { /* Message receive by bank B */
        
          /* This is place for your code */
          
          /* You can set up out going messade */
        	
        		/* Set up the message to transmit												*/
        	echoTransmitBuffer[0] = 20;			// repeats
        	echoTransmitBuffer[1] = 5;			// spacing
        	echoTransmitBuffer[2] = ECHO_ID_VALUE_B;		// ID
        	echoTransmitBuffer[3] = 3;			// data length
        	echoTransmitBuffer[4] = 0x25;			// example data
        	echoTransmitBuffer[5] = 0x68;			// second example data byte
          echoTransmitBuffer[5] = 0x72;			// third example data byte
         
          send_flag = SEND_B;
          
        }
        echoNextMessage[1] &= ~ECHO_BUFFER_FULL;            /* Clear full buffer flag */
      }else
      {
         /* Refuse a message */ 
        echoNextMessage[1] &= ~ECHO_BUFFER_FULL;            /* Clear full buffer flag */
      }   
    }  


    if(send_flag)    /* send any message? */
    {
      while(Echo_DriverStatus().Bits.Busy == 1); /* wait until driver be ready */
      if(send_flag == SEND_A)              /* which bank will be transmit */
      {
        Echo_ChangeBank(ECHO_BANK_A);      /* set bank A */
        
      }else
      {
        Echo_ChangeBank(ECHO_BANK_B);      /* set bank B */
      }
        
      while(Echo_DriverStatus().Bits.Busy == 1);  /* wait until driver be ready */
      Echo_SendMessage();                        /* Send message */
      send_flag = 0;   /* clear sending flag */
      /* After message be send, driver automaticaly switch echo to two bank mode /
       because in header file Echo.h is set #define ECHO_AUTO_SWITCH  1 */
    }

  } /* loop forever */
  /* please make sure that you never leave this function */
}


